"use strict";

/* eslint-disable no-console */

import React, { memo, useCallback, useEffect, useState } from 'react';
import { ScrollView, StyleSheet, Text, View } from 'react-native';
import { useShiki } from './SyntaxContext';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
export const SyntaxHighlighter = /*#__PURE__*/memo(({
  code,
  language,
  theme = 'github-dark',
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = useShiki();
  const [tokens, setTokens] = useState([]);
  const [error, setError] = useState(null);
  const highlight = useCallback(async () => {
    if (!highlighter || !isReady) return;
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      const normalizedLang = language.toLowerCase();
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      const themeName = typeof theme === 'string' ? theme : theme?.name || 'default-theme';
      log('Highlighting with:', {
        lang: effectiveLang,
        theme: themeName
      });

      // Get the theme details first
      const themeData = highlighter.getTheme(themeName);
      log('Theme details:', {
        name: themeData.name,
        type: themeData.type,
        settingsCount: themeData.settings?.length,
        colors: Object.keys(themeData.colors || {}).length
      });

      // Try to tokenize with full theme info
      const results = highlighter.codeToTokens(code, {
        lang: effectiveLang,
        theme: themeName,
        includeExplanation: true
      });
      log('Tokenization result:', {
        lines: results.tokens.length,
        firstLine: results.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          scopes: t.explanation?.[0]?.scopes
        }))
      });
      setTokens(results.tokens);
      setError(null);
    } catch (err) {
      console.error('Full highlighting error:', err);
      setError(err instanceof Error ? err.message : 'Failed to highlight code');
    }
  }, [code, language, theme, highlighter, isReady]);
  useEffect(() => {
    highlight();
  }, [highlight]);
  useEffect(() => {
    if (tokens.length > 0) {
      log('Rendering tokens:', {
        lineCount: tokens.length,
        tokensPerLine: tokens.map(line => line.length),
        firstLine: tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          scopes: t.explanation?.[0]?.scopes
        }))
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/_jsx(View, {
      style: styles.container,
      children: /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/_jsxs(View, {
      style: styles.container,
      children: [/*#__PURE__*/_jsx(Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/_jsx(Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/_jsx(ScrollView, {
    horizontal: true,
    style: styles.container,
    contentContainerStyle: {
      padding: 10
    },
    children: /*#__PURE__*/_jsx(View, {
      children: tokens.map((line, i) => /*#__PURE__*/_jsx(View, {
        style: styles.line,
        children: line.map((token, j) => {
          if (i === 0 && j < 3) {
            log('Rendering token:', {
              content: token.content,
              color: token.color,
              scopes: token.explanation?.[0]?.scopes
            });
          }
          return /*#__PURE__*/_jsx(Text, {
            style: {
              color: token.color || '#e1e4e8',
              fontSize,
              ...(token.fontStyle && token.fontStyle & 1 && {
                fontStyle: 'italic'
              }),
              ...(token.fontStyle && token.fontStyle & 2 && {
                fontWeight: 'bold'
              }),
              backgroundColor: token.bgColor
            },
            children: token.content
          }, `${i}-${j}`);
        })
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map