/* eslint-disable no-console */
import type { HighlighterCore, LanguageRegistration, ThemeRegistrationAny } from '@shikijs/types'
import { createHighlighterCore } from '@shikijs/core'

import { createJavaScriptRegexEngine } from '@shikijs/engine-javascript'
import React, { createContext, useContext, useEffect, useMemo, useState } from 'react'

const DEBUG = true
function log(...args: any[]) {
  if (DEBUG)
    console.log('[ShikiProvider]', ...args)
}

interface ShikiContextValue {
  highlighter: HighlighterCore | null
  isReady: boolean
  error: Error | null
}

interface ShikiProviderProps {
  children: React.ReactNode
  initialLanguages: LanguageRegistration[]
  initialThemes: ThemeRegistrationAny[]
}

const ShikiContext = createContext<ShikiContextValue | null>(null)

export function ShikiProvider({ children, initialLanguages, initialThemes }: ShikiProviderProps) {
  const [highlighter, setHighlighter] = useState<HighlighterCore | null>(null)
  const [isReady, setIsReady] = useState(false)
  const [error, setError] = useState<Error | null>(null)

  useEffect(() => {
    const init = async () => {
      try {
        log('Starting highlighter initialization')
        log(
          'Languages:',
          initialLanguages.map(l => l.name),
        )
        log(
          'Themes:',
          initialThemes.map(t => t.name),
        )

        const engine = createJavaScriptRegexEngine({
          forgiving: true,
          cache: new Map(),
        })

        // The languages are already in the correct format from shiki
        const instance = await createHighlighterCore({
          langs: initialLanguages, // Direct use of imported languages
          themes: initialThemes,
          engine,
        })

        // Verify languages loaded
        const loadedLangs = instance.getLoadedLanguages()
        log('Successfully loaded languages:', loadedLangs)

        // Test tokenization with typescript
        try {
          const test = instance.codeToTokens('const x: number = 1', {
            lang: 'typescript',
            theme: initialThemes[0]?.name || 'github-dark',
            includeExplanation: true,
          })

          log('Test tokenization successful:', {
            lineCount: test.tokens.length,
            firstLineTokens: test.tokens[0]?.map(t => ({
              content: t.content,
              color: t.color,
              scopes: t.explanation?.[0]?.scopes,
            })),
          })
        }
        catch (e) {
          log('Test tokenization failed:', e)
        }

        setHighlighter(instance)
        setIsReady(true)
      }
      catch (err) {
        console.error('Failed to initialize highlighter:', err)
        setError(err instanceof Error ? err : new Error('Failed to initialize highlighter'))
      }
    }

    init()
  }, [])

  const value = useMemo(
    () => ({
      highlighter,
      isReady,
      error,
    }),
    [highlighter, isReady, error],
  )

  return <ShikiContext.Provider value={value}>{children}</ShikiContext.Provider>
}

export function useShiki() {
  const context = useContext(ShikiContext)
  if (!context) {
    throw new Error('useShiki must be used within a ShikiProvider')
  }
  return context
}
