/* eslint-disable no-console */
import type { ThemedToken, ThemeRegistrationAny } from '@shikijs/types'
import React, { memo, useCallback, useEffect, useState } from 'react'
import { ScrollView, StyleSheet, Text, View } from 'react-native'
import { useShiki } from './SyntaxContext'

const DEBUG = true
function log(...args: any[]) {
  if (DEBUG)
    console.log('[SyntaxHighlighter]', ...args)
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap',
  },
})

interface SyntaxHighlighterProps {
  code: string
  language: string
  theme?: string | ThemeRegistrationAny
  fontSize?: number
}

export const SyntaxHighlighter = memo(({ code, language, theme = 'github-dark', fontSize = 14 }: SyntaxHighlighterProps) => {
  const { highlighter, isReady } = useShiki()
  const [tokens, setTokens] = useState<ThemedToken[][]>([])
  const [error, setError] = useState<string | null>(null)

  const highlight = useCallback(async () => {
    if (!highlighter || !isReady)
      return

    try {
      const loadedLangs = highlighter.getLoadedLanguages()
      const normalizedLang = language.toLowerCase()
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text'
      const themeName = typeof theme === 'string' ? theme : theme?.name || 'default-theme'

      log('Highlighting with:', {
        lang: effectiveLang,
        theme: themeName,
      })

      // Get the theme details first
      const themeData = highlighter.getTheme(themeName)
      log('Theme details:', {
        name: themeData.name,
        type: themeData.type,
        settingsCount: themeData.settings?.length,
        colors: Object.keys(themeData.colors || {}).length,
      })

      // Try to tokenize with full theme info
      const results = highlighter.codeToTokens(code, {
        lang: effectiveLang,
        theme: themeName,
        includeExplanation: true,
      })

      log('Tokenization result:', {
        lines: results.tokens.length,
        firstLine: results.tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          scopes: t.explanation?.[0]?.scopes,
        })),
      })

      setTokens(results.tokens)
      setError(null)
    }
    catch (err) {
      console.error('Full highlighting error:', err)
      setError(err instanceof Error ? err.message : 'Failed to highlight code')
    }
  }, [code, language, theme, highlighter, isReady])

  useEffect(() => {
    highlight()
  }, [highlight])

  useEffect(() => {
    if (tokens.length > 0) {
      log('Rendering tokens:', {
        lineCount: tokens.length,
        tokensPerLine: tokens.map(line => line.length),
        firstLine: tokens[0]?.map(t => ({
          content: t.content,
          color: t.color,
          scopes: t.explanation?.[0]?.scopes,
        })),
      })
    }
  }, [tokens])

  if (!isReady) {
    return (
      <View style={styles.container}>
        <Text style={{ fontSize }}>{code}</Text>
      </View>
    )
  }

  if (error) {
    return (
      <View style={styles.container}>
        <Text style={{ color: 'red' }}>{error}</Text>
        <Text style={{ fontSize }}>{code}</Text>
      </View>
    )
  }

  return (
    <ScrollView horizontal style={styles.container} contentContainerStyle={{ padding: 10 }}>
      <View>
        {tokens.map((line, i) => (
          <View key={i} style={styles.line}>
            {line.map((token, j) => {
              if (i === 0 && j < 3) {
                log('Rendering token:', {
                  content: token.content,
                  color: token.color,
                  scopes: token.explanation?.[0]?.scopes,
                })
              }

              return (
                <Text
                  key={`${i}-${j}`}
                  style={{
                    color: token.color || '#e1e4e8',
                    fontSize,
                    ...(token.fontStyle && token.fontStyle & 1 && { fontStyle: 'italic' }),
                    ...(token.fontStyle && token.fontStyle & 2 && { fontWeight: 'bold' }),
                    backgroundColor: token.bgColor,
                  }}
                >
                  {token.content}
                </Text>
              )
            })}
          </View>
        ))}
      </View>
    </ScrollView>
  )
})
